<?php

use DI\Container;
use Noodlehaus\Config;
use Noodlehaus\Parser\Json;
use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;
use Slim\Factory\AppFactory;
use Slim\Views\Twig;
use Slim\Views\TwigMiddleware;

use BitGoblin\Colossus\Middleware\AppInfo;

require __DIR__ . '/../vendor/autoload.php';

// Load app configuration
$config = Config::load(__DIR__ . '/../conf/defaults.json');

// Create new container object and add our config object to it
$container = new Container();
$container->set('config', function () use ($config) {
  return $config;
});

// Load database configuration
require_once __DIR__ . '/database.php';

// Set container to create App with on AppFactory
AppFactory::setContainer($container);
$app = AppFactory::create();

// Allow body parsing for POST parameters
$app->addBodyParsingMiddleware();

// Add Error Handling Middleware
$app->addErrorMiddleware(true, false, false);

// Create Twig
$twig = Twig::create(__DIR__ . '/../views', ['cache' => false]);
// Add Twig-View Middleware
$app->add(TwigMiddleware::create($app, $twig));

// Add middleware for injecting global vars for app's info
$app->add(new AppInfo($twig));

// Register routes
require_once __DIR__ . '/routes.php';
